/*************************************************************
 *     SDL Tutorial aus dem deutschen Pandora Wiki
 *     http://wiki.openpandora.de/
 *
 * 	   Hilfe und Support gibt es im offiziellen Pandora Forum
 * 	   http://forum.gp2x.de/
 *
 *     Author: Thrake
 *************************************************************/

#include "engine.h"

Engine::Engine()
{

}

Engine::~Engine()
{

}

bool Engine::init()
{

    if( SDL_Init( SDL_INIT_EVERYTHING ) == -1 )
    {
    	std::cerr << "Fehler: libSDL wurde nicht gefunden" << std::endl;
        return false;
    }

    screen = SDL_SetVideoMode( SWIGHT, SHEIGHT, SBPP , 0x00000011 );
    if( screen == NULL ) return false;

    SDL_WM_SetCaption( "Hello World", NULL );

    if( TTF_Init() == -1 )
    {
    	std::cerr << "Fehler: SDL_TTF wurde nicht gefunden" << std::endl;
    	return false;
    }

    return true;

}

SDL_Surface* Engine::getSurface(std::string filename)
{
	SDL_Surface *temp_img = NULL;

	temp_img = IMG_Load(filename.c_str());

#ifdef _DEBUG
	if (temp_img == NULL)
	{
		std::cout << "Fehler: Die Datei " << filename.c_str() << " konnte nicht gefunden werden" << std::endl;
		return NULL;
	}
#endif

	temp_img = SDL_DisplayFormat(temp_img);
	return temp_img;

}

SDL_Surface* Engine::getText(std::string text,Farbe clr)
{
	SDL_Color sFarbe;
	TTF_Font* font = TTF_OpenFont( "LiberationSerif-Bold.ttf", 100 );
	SDL_Surface* tmpSurface;
	switch(clr)
	{
	case ROT:
		sFarbe.r = 255;
		sFarbe.g = 0;
		sFarbe.b = 0;
	break;

	case GELB:
		sFarbe.r = 255;
		sFarbe.g = 255;
		sFarbe.b = 0;
	break;

	case GRUEN:
		sFarbe.r = 0;
		sFarbe.g = 255;
		sFarbe.b = 0;
	break;

	case BLAU:
		sFarbe.r = 0;
		sFarbe.g = 0;
		sFarbe.b = 255;
	break;

	case SCHWARZ:
		sFarbe.r = 0;
		sFarbe.g = 0;
		sFarbe.b = 0;
	break;

	case WEISS:
		sFarbe.r = 255;
		sFarbe.g = 255;
		sFarbe.b = 255;
	break;

	default: std::cout << "Es wurde eine falsche Farbe angegeben." << std::endl;

	}

	tmpSurface = TTF_RenderText_Blended( font, text.c_str(), sFarbe );

	return tmpSurface;

}


void Engine::addSurface( int x, int y, SDL_Surface* temp_surface)
{
    SDL_Rect offset;
    offset.x = x;
    offset.y = y;

    SDL_BlitSurface( temp_surface, NULL, screen, &offset );

}

void Engine::refreshScreen()
{
	if( SDL_Flip( screen ) == -1 ) std::cerr << "Fehler beim Aktualisieren des Screens" << std::endl;
}

void Engine::paintBox(int x1, int y1, int x2, int y2, Farbe clr)
{
	switch(clr)
	{
	case ROT: boxRGBA(screen, x1, y1, x2, y2, 255, 0, 0, 255);
	break;

	case GELB: boxRGBA(screen, x1, y1, x2, y2, 255, 255, 0, 255);
	break;

	case GRUEN: boxRGBA(screen, x1, y1, x2,	y2, 0, 255, 0, 255);
	break;

	case BLAU: boxRGBA(screen, x1, y1, x2, y2, 0, 0, 255, 255);
	break;

	case SCHWARZ: boxRGBA(screen, x1, y1, x2, y2, 0, 0, 0, 255);
	break;

	case WEISS: boxRGBA(screen, x1, y1, x2,	y2, 255, 255, 255, 255);
	break;

	default: std::cout << "Es wurde eine falsche Farbe angegeben." << std::endl;

	}

}

